/*
 * T-Plan Robot Enterprise, automated testing tool.
 * Copyright (C) 2009-2013 T-Plan Limited (http://www.t-plan.com),
 * Cloisters House, 8 Battersea Park Road, London, SW8 4BG, United Kingdom.
 * All rights reserved.
 */
package com.tplan.db;

import com.tplan.robot.preferences.Preference;
import com.tplan.robot.scripting.ParametrizedTestScript;
import java.sql.Connection;
import java.sql.DatabaseMetaData;
import java.sql.SQLException;
import java.util.List;
import java.util.Map;

/**
 * Java test script which disconnects (closes) the current database connection.
 */
public class Disconnect extends AbstractDbScript implements ParametrizedTestScript {

    @Override
    public void test() {
        // Remove the connection pool key from the context.
        String poolKey = (String) getContext().remove(Connect.CONTEXT_OBJECT_DB_URL);
        if (poolKey != null) {

            // Close the connection
            final Map<String, ConnectionBean> conns = connectionPool;
            synchronized (conns) {
                ConnectionBean bean = conns.remove(poolKey);
                Connection conn = bean == null ? null : bean.connection;
                if (conn != null) {
                    try {
                        StringBuilder log = new StringBuilder();
                        DatabaseMetaData metaData = conn.getMetaData();
                        log.append("Closed connection to ").append(metaData.getDatabaseProductName());
                        log.append(" ").append(metaData.getDatabaseProductVersion());
                        log.append(" (").append(metaData.getURL()).append(")");
                        getContext().getExecutionLog().logInfo(log.toString());
                    } catch (SQLException ex) {
                    }
                    try {
                        conn.close();
                    } catch (SQLException ex) {
                        ex.printStackTrace();
                    }
                }
            }
        }
        setVariable("_EXIT_CODE", "0");
    }

    public List<String> getParameters() {
        return null;
    }

    public List getParameterValues(String parameterName) {
        return null;
    }

    public void setParameters(Map<String, String> paramsAndValues) {
    }

    public List<Preference> getVisualParameters() {
        return null;
    }

    public String getShortDescription() {
        return "Disconnect the current DB connection.";
    }

    public String getLongDescription() {
        return getShortDescription();
    }
}
